.. toctree::
   :maxdepth: 2
   :caption: Contents:

   Overview <README.md>
   Installation <installation>
   Image Data Formats <image>
   Usage <usage>
   Commnand Line Usage <cmd_usage>
   Contributing <contributing>
   Authors <authors>
   History <history>
   wsireg API Reference <modules>


Indices and tables
==================
* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
